@@ -1,5 +1,8 @@
+#![feature(rustc_private)]
+
+extern crate rustc_interface;
+
 use clap::clap_app;
-use rustc_version_runtime::version_meta;
 use std::{
   env,
   process::{exit, Command},
@@ -8,8 +11,8 @@ use std::{
 fn main() {
   let flowistry_rustc_path = std::env::current_exe()
     .expect("current executable path invalid")
-    .with_file_name("flowistry-rustc");
-  let cargo_path = env::var("CARGO_PATH").unwrap_or("cargo".to_string());
+    .with_file_name("flowistry-driver");
+  let cargo_path = env::var("CARGO_PATH").unwrap_or_else(|_| "cargo".to_string());
 
   let matches = clap_app!(app =>
     (version: "0.1")
@@ -28,34 +31,46 @@ fn main() {
       (@arg end:)
       (@arg flags: ...)
     )
+    (@subcommand effects =>
+      (@arg file:)
+      (@arg pos:)
+      (@arg flags: ...)
+    )
   )
   .get_matches_from(env::args().skip(1));
 
-  let (args, flags) = match matches.subcommand() {
+  let mut args = match matches.subcommand() {
     ("rustc_version", _) => {
-      println!("{}", version_meta().commit_hash.unwrap());
+      let commit_hash = rustc_interface::util::commit_hash_str().unwrap_or("unknown");
+      println!("{}", commit_hash);
       exit(0);
     }
-    (cmd @ ("backward_slice" | "forward_slice"), Some(sub_m)) => (
-      vec![
-        ("COMMAND", cmd),
-        ("FILE", sub_m.value_of("file").unwrap()),
-        ("START", sub_m.value_of("start").unwrap()),
-        ("END", sub_m.value_of("end").unwrap()),
-      ],
-      sub_m.value_of("flags"),
-    ),
+    ("backward_slice" | "forward_slice", Some(sub_m)) => vec![
+      ("FILE", sub_m.value_of("file").unwrap()),
+      ("START", sub_m.value_of("start").unwrap()),
+      ("END", sub_m.value_of("end").unwrap()),
+    ],
+    ("effects", Some(sub_m)) => vec![
+      ("FILE", sub_m.value_of("file").unwrap()),
+      ("POS", sub_m.value_of("pos").unwrap()),
+    ],
     _ => {
       unimplemented!()
     }
   };
 
+  let (cmd, flags) = match matches.subcommand() {
+    (cmd, Some(sub_m)) => (cmd, sub_m.value_of("flags")),
+    _ => unimplemented!(),
+  };
+  args.push(("COMMAND", cmd));
+
   let mut cmd = Command::new(cargo_path);
   cmd
     .arg("check")
     .arg("-q")
     .args(flags)
-    .env("RUSTC_WRAPPER", flowistry_rustc_path);
+    .env("RUSTC_WORKSPACE_WRAPPER", flowistry_rustc_path);
 
   for (k, v) in args {
     cmd.env(format!("FLOWISTRY_{}", k), v);
